<h2 align="center">Py Watch Power</h2>

<p align="center">
<a href="https://pypi.org/project/py-watch-power/"><img src="https://img.shields.io/pypi/l/py-watch-power?style=for-the-badge" title="License: GPL-3"/></a> 
<a href="https://pypi.org/project/py-watch-power/"><img src="https://img.shields.io/pypi/pyversions/py-watch-power?style=for-the-badge" title="Python Versions"/></a> 
<a href="https://github.com/psf/black/"><img src="https://img.shields.io/badge/Code%20Style-black-black?style=for-the-badge" title="Code style: black"/></a> 
<a href="https://pypi.org/project/py-watch-power/"><img src="https://img.shields.io/pypi/v/py-watch-power?style=for-the-badge" title="PyPy Version"/></a> 
<a href="https://pypi.org/project/py-watch-power/"><img src="https://img.shields.io/pypi/dm/py-watch-power?style=for-the-badge" title="PyPy Downloads"/></a> 
<br>
<a href="https://github.com/corvis/py-watch-power/actions/workflows/sanity-check.yml"><img src="https://img.shields.io/github/workflow/status/corvis/py-watch-power/Sanity%20Check?style=for-the-badge" title="Build Status"/></a> 
<a href="https://github.com/corvis/py-watch-power/"><img src="https://img.shields.io/github/last-commit/corvis/py-watch-power?style=for-the-badge" title="Last Commit"/></a> 
<a href="https://github.com/corvis/py-watch-power/releases/"><img src="https://img.shields.io/github/release-date/corvis/py-watch-power?style=for-the-badge" title="Last Release"/></a> 
</p>

# Credits

* Dmitry Berezovsky, author
* David Nedved, developer of
  the [docker-voltronic-homeassistant](https://github.com/ned-kelly/docker-voltronic-homeassistant), which was used as a
  reference and a source of inspiration.
* 'Skymax', who did original research on the protocol
  and [published it on his blog](https://skyboo.net/2017/03/monitoring-voltronic-power-axpert-mex-inverter-under-linux/).

# Disclaimer

This module is licensed under GPL-3.0. It doesn't allow you to use it in a commercial product without making your
product open source and comes with no warranty. Please see the included LICENSE file for details.
